@@ -10,7 +10,7 @@ use parent 'RPi::WiringPi::Util';
 use RPi::WiringPi::Constant qw(:all);
 use RPi::WiringPi::Interrupt;
 
-our $VERSION = '2.3610';
+our $VERSION = '2.3611';
 
 sub new {
     my ($class, $pin) = @_;
@@ -64,7 +64,6 @@ sub pull {
         die "Core::pull_up_down requires either 0, 1 or 2 for direction";
     }
 
-    $self->mode(INPUT);
     $self->pull_up_down($self->num, $direction);
 }
 sub pwm {
@@ -88,10 +87,7 @@ sub num {
 }
 sub interrupt_set {
     my ($self, $edge, $callback) = @_;
-    #$self->set_interrupt($self->num, $edge, $callback);
-    my $int = RPi::WiringPi::Interrupt->new;
-    $int->set($self->num, $edge, $callback);
-    $self->{interrupt} = $int;
+    $self->set_interrupt($self->num, $edge, $callback);
 }
 sub _soft_pwm_enabled {
     my ($self, $enabled) = @_;
@@ -120,7 +116,7 @@ RPi::WiringPi::Pin - Access and manipulate Raspberry Pi GPIO pins
     $pin->mode(INPUT);
     $pin->write(LOW);
 
-    $pin->set_interrupt(EDGE_RISING, 'pin5_interrupt_handler');
+    $pin->set_interrupt(EDGE_RISING, 'main::pin5_interrupt_handler');
 
     my $num = $pin->num;
     my $mode = $pin->mode;
@@ -210,7 +206,8 @@ C<EDGE_BOTH>.
 
 The string name of a Perl subroutine that you've already written within your
 code. This is the interrupt handler. When an interrupt is triggered, the code
-in this subroutine will run.
+in this subroutine will run. If you get errors when the handler is called,
+specify the full package name to the handler (eg: C<'main::callback'>).
 
 =head2 pwm($value)
 
